from .. import Provider as BaseProvider


class Provider(BaseProvider):
    """
    Source: https://star.dk/it/saadan-arbejder-vi-med-it-i-styrelsen/oversigt-over-stillingsbetegnelser-og-kvalifikationer/.  # NOQA
    """

    jobs = [
        "Lastvognsmekanikerlærling",
        "Knallertmekaniker",
        "Møbelarkitekt",
        "Forsyningsoperatørelev",
        "Hospitalsfysiker",
        "Økonomicontroller",
        "Revisor",
        "Skatterevisor",
        "Kontrollør",
        "Musikpædagog",
        "Pantefoged",
        "Serveringsmedarbejder",
        "Maskinmesteraspirant",
        "Sygehusdirektør",
        "Laborant",
        "Overlæge",
        "Designassistent",
        "Teknisk chef",
        "Socialformidler",
        "Overassistent",
        "Pædagogisk assistent",
        "Pedel",
        "Kustode",
        "Pædagogmedhjælper",
        "Projektmedarbejder",
        "Pedelmedhjælper",
        "Museumsbetjent",
        "Molekylærbiolog",
        "Lærervikar",
        "Sognehjælper",
        "Lysdesigner",
        "Instruktørassistent",
        "Teatertekniker",
        "Researcher",
        "Redaktør",
        "Teknisk designer",
        "Ressourceleder",
        "Indkøbschef",
        "E-commerce manager",
        "Kontraktchef",
        "Produktchef",
        "Museumsinspektør",
        "Kurator",
        "Konservator",
        "Modelkonstruktør",
        "Kommunikationschef",
        "Forskningschef",
        "Skovrider",
        "Fiskeriteknolog",
        "Produktionschef",
        "Driftsleder",
        "Direktør",
        "Officer",
        "Sergent",
        "IT-ingeniør",
        "IT-arkitekt",
        "IT-revisor",
        "Programmør og systemudvikler",
        "UX designer",
        "Webredaktør",
        "Webudvikler",
        "Datakonsulent",
        "Idrætsinstruktør og -konsulent",
        "Efterretningsofficer",
        "Miljøkonsulent",
        "Campingpladsbestyrer",
        "Miljøkoordinator",
        "Grafisk tekniker",
        "Elektrotekniker",
        "Vindmølleoperatør",
        "Urmager",
        "Byplanlægger",
        "Trafikplanlægger",
        "GIS-medarbejder",
        "Illustrator",
        "Mediegrafiker",
        "Artdirector",
        "Multimediedesigner",
        "Praktiserende læge",
        "Speciallæge",
        "Struktør",
        "Pakkerimedarbejder",
        "Cykelbud",
        "Fabriksbager",
        "Møller",
        "Guld- og sølvsmed",
        "Ciselør",
        "Produktionsleder inden for film og teater",
        "Centerleder",
        "Lufthavnschef",
        "Kameramand",
        "Tonemester",
        "Studietekniker",
        "Eventtekniker",
        "Produktionstekniker",
        "Fødevareteknolog",
        "Brygmester",
        "Specialist i biomedicin",
        "Botaniker",
        "Biokemiker",
        "Havbiolog",
        "Fysiolog",
        "Planteforædler",
        "Skoleleder",
        "Døvekonsulent",
        "Import- og eksportmedarbejder",
        "Friskolelærer",
        "Au pair",
        "Børnepasser",
        "Landbrugsmaskinemekaniker",
        "Trafikinformationsmedarbejder",
        "Togfører",
        "Guide",
        "Kok",
        "Vært i restaurant",
        "Tjener",
        "Bartender",
        "Korrekturlæser",
        "Postfunktionær",
        "Biblioteksassistent",
        "Telefonist",
        "Kundeservicemedarbejder",
        "Natportier",
        "Interviewer",
        "Vekselbureaumedarbejder",
        "Skattefunktionær",
        "Forsikringsfunktionær",
        "Revisorassistent",
        "Lønbogholder",
        "Lagerforvalter",
        "Overstyrmand",
        "Flyklarerer",
        "Marketingmedarbejder",
        "Kreativ chef",
        "Miljøanalytiker",
        "Naturvejleder",
        "Procesingeniør",
        "Logistiker",
        "Bankdirektør",
        "Civilingeniør",
        "Miljøingeniør",
        "Maskiningeniør",
        "Værkstedsleder",
        "Programdirektør",
        "Lystekniker",
        "IT-supporter",
        "IT-tekniker",
        "IT-kvalitetsmedarbejder",
        "Korleder",
        "Marketingchef",
        "Destinationschef",
        "Ordblindelærer",
        "Kursusleder",
        "Produktspecialist",
        "Områdechef",
        "Rengøringsinspektør",
        "Smedelærling",
        "Stenhuggerlærling",
        "Shippingmedarbejder",
        "Lager- og logistikelev",
        "Stukkatørlærling",
        "Automekanikerlærling",
        "Beklædningshåndværkerelev",
        "Butikselev",
        "Datateknikerelev",
        "Industrislagterlærling",
        "Shippingassistent",
        "Konditorlærling",
        "Gulvlæggerlærling",
        "Køleteknikerlærling",
        "Bygningstruktørlærling",
        "Rustfast industrimontør",
        "Værktøjsmagerlærling",
        "Industriteknikerlærling",
        "Vagtcentralassistent",
        "Juridisk chef",
        "Kunstlærer",
        "Lærer på skuespillerskole",
        "Asfaltør",
        "Jordemoder",
        "Erhvervsskolelærer",
        "Personalekonsulent",
        "Job- og virksomhedskonsulent",
        "Tekstforfatter",
        "Virksomhedsudvikler",
        "Byggeleder",
        "Departementschef",
        "Politidirektør",
        "Diplomat",
        "Generalsekretær",
        "Leder af offentlig forvaltning",
        "Konstabel",
        "Speditør",
        "Flyttearbejder",
        "Lager- og logistikmedarbejder",
        "Havnearbejder",
        "Anlægsarbejder",
        "Slagteriarbejder",
        "Fiskeindustriarbejder",
        "Industrislagter",
        "Slagtermester",
        "Bager",
        "Konditor",
        "Mejeriarbejder",
        "Mejerist",
        "Familievejleder",
        "Socialfaglig leder",
        "HR-konsulent",
        "SSP-medarbejder",
        "Havnefoged",
        "Lufthavnsoperatør",
        "Assistent til salgssupport",
        "Frisør",
        "Model",
        "Demonstratør",
        "Call centermedarbejder",
        "Viceskoleleder",
        "Ortopædiskomager",
        "Fiskeribetjent",
        "Indkøber",
        "Massageterapeut",
        "Levnedsmiddelinspektør",
        "Ambulancefører",
        "Paramediciner",
        "Kunstformidler",
        "Arkivar",
        "Registrar",
        "Bibliotekar",
        "Økonom",
        "Antropolog",
        "Arkæolog",
        "Motorcykelmekanikerlærling",
        "Skibsmekanikerlærling",
        "Landbrugsmaskine-mekanikerlærling",
        "VVS-lærling",
        "Privatpraktiserende tandplejer",
        "Glarmesterlærling",
        "Ejendomsserviceteknikerelev",
        "Audiologiassistentelev",
        "Dyrepasserelev",
        "Tømrerlærling",
        "Autolakererlærling",
        "Bygningsmalerlærling",
        "Automatikteknikerelev",
        "Skorstensfejerlærling",
        "Bagerlærling",
        "Vagtcentralmedarbejder",
        "Murerlærling",
        "Elektrikerlærling",
        "Rørlægger",
        "Flymekanikerlærling",
        "Cykelmekanikerlærling",
        "Skibsmontørlærling",
        "Bygningssnedkerlærling",
        "Studentermedhjælp",
        "Redder",
        "Chaufførelev",
        "Slagterlærling",
        "Tagdækkerlærling",
        "Organist",
        "Sagsbehandler",
        "Databaseadministrator",
        "Bankrådgiver",
        "Realkreditmedarbejder",
        "Bogholder",
        "Bogholderi- og regnskabsassistent",
        "Assurandør",
        "Valuar",
        "Taksator",
        "Hardware-udvikler",
        "Medicoingeniør",
        "Sensortekniker",
        "Boghandler",
        "Ekspedient",
        "Fiskehandler",
        "Farvehandler",
        "Blomsterbinder",
        "Delikatesseassistent",
        "Farmakonom",
        "Serviceøkonom",
        "SOME-medarbejder",
        "Pressesekretær",
        "Fundraiser",
        "Kampagnemedarbejder",
        "Kommunikationskonsulent",
        "IT-konsulent",
        "IT-direktør",
        "IT-chef",
        "IT-dokumentationschef",
        "Chief data officer",
        "IT-projektleder",
        "Børne- og ungekoordinator",
        "Leder af børne- og ungdomsklub",
        "Børsmægler",
        "Lagerekspedient",
        "Sommelier",
        "Levnedsmiddelingeniør",
        "Vagt",
        "Dørmand",
        "Barista",
        "Tekster",
        "Flyinstruktør",
        "Helikopterfører",
        "Flymaskinist",
        "Klimaforsker",
        "Handelsskolelærer",
        "Møbelpolstrer",
        "Børneværnskonsulent",
        "Klargører",
        "Klubmedarbejder",
        "Kontorchef",
        "Koordinator",
        "Efterskoleforstander",
        "Vicerektor",
        "Politisk medarbejder",
        "Politisk konsulent",
        "Kommunal planlægger",
        "Fuldmægtig",
        "Rådgivende konsulent",
        "Business intelligence manager",
        "Økonomiassistent",
        "Finansanalytiker",
        "Gymnasielærer",
        "Folkeskolelærer",
        "Pædagog",
        "Studiesekretær",
        "Speciallærer",
        "Fotografmedhjælper",
        "Erhvervsdykker",
        "Danselærer",
        "Geograf",
        "Kriminolog",
        "Sociolog",
        "Historiker",
        "Filosof",
        "Socialrådgiver",
        "Politolog",
        "Psykolog",
        "Socialarbejder",
        "Socialpædagog",
        "Præst",
        "Geotekniker",
        "Svejseinspektør",
        "Designer",
        "Merchandiser",
        "Visual merchandiser",
        "Scenograf",
        "Tandklinikassistent",
        "Tandplejer",
        "Keramiker",
        "Gravør",
        "Kunstner",
        "Tegner",
        "Garver",
        "Landinspektør",
        "Byggemontagetekniker",
        "Brolægger",
        "Forskningsbibliotekar",
        "Anlægsgartnerarbejder",
        "Cafemedarbejder",
        "Kontorleder",
        "Farmakonomelev",
        "Rejsebureauelev",
        "Tandplejerelev",
        "Tandteknikerelev",
        "Frisørelev",
        "Receptionistelev",
        "Vejrvært",
        "Arrangementchef",
        "Udviklingschef",
        "Indretningsarkitekt",
        "Autoteknolog",
        "Butiksassistent",
        "Skolepædagog",
        "Social- og sundhedsassistent",
        "Social- og sundhedshjælper",
        "Kasseassistent",
        "Levnedsmiddeltekniker",
        "Maskinsnedker",
        "Møbelsnedker",
        "Automationsingeniør",
        "Produktionsmedarbejder",
        "Byggetekniker",
        "Reklamechef",
        "Sproglærer",
        "Tegnsprogslærer",
        "Energiingeniør",
        "Dagtilbudsleder",
        "Vuggestueleder",
        "Plejehjemsleder",
        "Kommunikationskoordinator",
        "Brandchef",
        "Flysikkerhedschef",
        "Miljø- og sikkerhedschef",
        "Bibliotekschef",
        "Museumsleder",
        "Kunstnerisk leder",
        "Kundeservicechef",
        "Rigsarkivar",
        "Flymekaniker",
        "Skibsmekaniker",
        "Entreprenørmaskinemekaniker",
        "Kranmekaniker",
        "Industrimekaniker",
        "Cykelmekaniker",
        "Skorstensfejer",
        "Industrilakerer",
        "Autolakerer",
        "Murer",
        "Stenhugger",
        "Betonmager",
        "Køkkenmontør",
        "Tømrer",
        "Skov- og naturteknikerelev",
        "Lægemiddelkonsulent",
        "Bevægelsespædagog",
        "Ernæringsassistent",
        "Ungdomsskolelærer",
        "PAU-elev",
        "IT-underviser",
        "VUC-lærer",
        "Uddannelses- og erhvervsvejleder",
        "Finansrådgiver",
        "Investeringsrådgiver",
        "Musiklærer",
        "Hotelchef",
        "Butikschef",
        "Regionschef",
        "Teaterteknikerelev",
        "Speditørelev",
        "IT-supporterelev",
        "Politielev",
        "Vindmølleoperatørelev",
        "Gartnerelev",
        "Ortopædielev",
        "Fotografelev",
        "Film- og tvproduktionselev",
        "Procesoperatørelev",
        "Optikerelev",
        "Radio- og TV-fagteknikerelev",
        "Handelselev",
        "Elektronikoperatørelev",
        "Toldelev",
        "Plastmagerelev",
        "Social- og sundhedshjælperelev",
        "Grafikerelev",
        "Forsikringselev",
        "Revisorelev",
        "Shippingelev",
        "Regnskabselev",
        "Tjenerelev",
        "Finmekanikerelev",
        "Oliefyrsteknikerelev",
        "Urmagerelev",
        "Redderelev",
        "Teleteknikerelev",
        "Industrioperatørelev",
        "Landbrugselev",
        "Kosmetologelev",
        "Asfaltørelev",
        "Kontorelev",
        "Fitnessinstruktørelev",
        "Møbelsnedkerelev",
        "Serviceassistentelev",
        "Mejerielev",
        "Ernæringsassistentelev",
        "Neurofysiologiassistentelev",
        "Kostumier",
        "Buntmager",
        "Parykmager",
        "Skrædder",
        "Skomager",
        "Bore- og udvindingsarbejder",
        "Offshorearbejder",
        "Ordrebehandler",
        "Reservedelsekspedient",
        "Oldfrue",
        "Vicevært",
        "Ledsager",
        "Bedemandsassistent",
        "Bedemand",
        "Graver",
        "Kosmetolog",
        "Stylist",
        "Negletekniker",
        "Massør",
        "Tekstildesigner",
        "Kostumedesigner",
        "Institutleder på universitet",
        "Rektor",
        "Information- og videnchef IT",
        "Dokumentationsmedarbejder",
        "Efterskolelærer",
        "Dagplejer",
        "Yogalærer",
        "Dommerfuldmægtig",
        "Hotelmedarbejder",
        "Dagplejeleder",
        "Kordegn",
        "FGU-lærer",
        "Værkstedsassistent",
        "Økonoma",
        "Artist",
        "Væksthusgartner",
        "Gartneriarbejder",
        "Chef for gartneriproduktion",
        "Anlægsgartner",
        "Staldmester",
        "Støberitekniker",
        "Skibsbygger",
        "Svejser",
        "Klejnsmed",
        "Laboratorieleder",
        "Skovfoged",
        "Fiskeassistent",
        "Fisker",
        "Skytte",
        "Landmand",
        "Pelsdyravler",
        "Fængselsfunktionær",
        "Livredder",
        "Nødhjælpsarbejder",
        "Parkeringsvagt",
        "Kældermester",
        "Fødevareinspektør",
        "Grossist",
        "Varemægler",
        "Skibsfører",
        "Lods",
        "Skibsmaskinist",
        "Maskinmester",
        "Maskinassistent",
        "Mejeritekniker",
        "Produktionsteknolog",
        "Produktionsleder",
        "Værkfører",
        "Fysiker",
        "Astronom",
        "Metrolog",
        "Meteorolog",
        "Kemiker",
        "Geofysiker",
        "Geolog",
        "Statistiker",
        "Aktuar",
        "Demograf",
        "Matematiker",
        "Farmakolog",
        "Biolog",
        "Skovbrugsrådgiver",
        "Landbrugskonsulent",
        "Agronom",
        "Sagsadministrator",
        "Detektiv",
        "Kontormedhjælper",
        "Sekretær",
        "Tasteoperatør",
        "Bankassistent",
        "Croupier",
        "Av tekniker",
        "Tekniker radio- og TV-udsendelser",
        "Webmaster",
        "Garderobeassistent",
        "Butiksdetektiv",
        "Beklædningsdesigner",
        "Psykoterapeut",
        "Klinisk psykolog",
        "Produktionsingeniør",
        "Regionsdirektør",
        "Havearkitekt",
        "Salgs- og kundeansvarlig",
        "Systemadministrator",
        "IT-sikkerhedskonsulent",
        "Eventmanager",
        "Eventassistent",
        "Ejendomsadministrator",
        "Ejendomsmægler",
        "Reklamekonsulent",
        "Auktionsleder",
        "Musiker",
        "Danser",
        "Koreograf",
        "Kirketjener",
        "Driftschef",
        "Chefkonsulent",
        "Turismechef",
        "Brandinspektør",
        "Testingeniør",
        "Materialetekniker",
        "Kemiingeniør",
        "Økonomichef",
        "Cykelhandler",
        "Bagermester",
        "Politifuldmægtig",
        "Musikterapeut",
        "Kvalitetsingeniør",
        "Hundetræner",
        "Beslagsmed",
        "Teatermedarbejder",
        "Scenefunktionær",
        "Sikkerhedschef",
        "Plade- og konstruktionssmed",
        "Smed",
        "Finmekaniker",
        "Værktøjsmager",
        "Modelsnedker",
        "Låsesmed",
        "Hundefører",
        "Medarbejder på et dyreinternat",
        "Kørelærer",
        "Instrumentbygger",
        "Lydtekniker",
        "Tandklinikassistentelev",
        "Museumsmedhjælper",
        "Bådebyggerlærling",
        "Teknisk isolatørelev",
        "VVS-montør",
        "Blikkenslager",
        "Galvanisør",
        "Bådebygger",
        "Lastvognsmekaniker",
        "Knallertmekanikerlærling",
        "Laboratorietekniker",
        "Skibsmontør",
        "Manuskriptforfatter",
        "Teknisk kommunikator",
        "Vulkanisør",
        "Veterinærsygeplejerske",
        "Inseminør",
        "Drejer",
        "CNC-operatør",
        "Jern- og metalsliber",
        "Karosserismed",
        "Automekaniker",
        "Dækmontør",
        "Mekaniker",
        "Filmklipper",
        "Producer",
        "Skuespiller",
        "Jordbrugsteknolog",
        "Miljøtekniker",
        "Kort- og landmålingstekniker",
        "Fræser",
        "Transportchef",
        "Porcelænsmaler",
        "Robottekniker",
        "Personalechef",
        "Programchef",
        "Chefstrateg",
        "Facility manager",
        "Administrationschef",
        "Kvalitetschef",
        "Kontorfuldmægtig",
        "Advokatsekretær",
        "Direktionssekretær",
        "Redaktionssekretær",
        "Lægesekretær",
        "Administrativ lægesekretær",
        "Tolder",
        "Teletekniker",
        "Elektrofagtekniker",
        "Pottemager",
        "Glarmester",
        "Glasmager",
        "Skiltemaler",
        "Klaverstemmer",
        "Kranfører",
        "Truckfører",
        "Sadelmager",
        "Trykkeriarbejder",
        "Tekstiltrykker",
        "Elektriker",
        "Dirigent",
        "Korsanger",
        "Ligestillings- og inklusionschef",
        "Akupunktør",
        "Orgelbygger",
        "Personlig træner",
        "Forlystelsesmedarbejder",
        "Renseriassistent",
        "Redaktionschef",
        "Distributionschef",
        "Lagerchef",
        "Import- og eksportchef",
        "Supply chain manager",
        "Elektronikarbejder",
        "Lokomotivfører",
        "Togklargører",
        "Taxichauffør",
        "Risikoanalytiker",
        "Værdipapiranalytiker",
        "Forsikringsanalytiker",
        "Investeringsanalytiker",
        "Sceneinstruktør",
        "Caster",
        "Filminstruktør",
        "Stilladsmontør",
        "Nedriver",
        "Brandmand",
        "Tagdækker",
        "Stukkatør",
        "Isolatør",
        "Kloakrørlægger",
        "Kloakmester",
        "VVS-installatør",
        "Gastekniker",
        "HVAC-tekniker",
        "Arbejdsmiljøkonsulent",
        "Fysioterapeut",
        "Ernærings- og sundhedskonsulent",
        "Audiolog",
        "Logopæd",
        "Øjenlæge",
        "Radiograf",
        "Kiropraktor",
        "Ergoterapeut",
        "Elektroingeniør",
        "Fodterapeut",
        "Alternativ behandler",
        "Lektor",
        "Oversygeplejerske",
        "Specialsygeplejerske",
        "Sygeplejerske",
        "Elektronikingeniør",
        "Telekommunikationsingeniør",
        "Arkitekt",
        "Landskabsarkitekt",
        "Industriel designer",
        "Vaskeriassistent",
        "Bryggeriarbejder",
        "Datalog",
        "Psykiatrisk sygeplejerske",
        "Ortopædist",
        "Designteknolog",
        "Skibsmægler",
        "Medicotekniker",
        "Finanschef",
        "Regnskabschef",
        "Filmfotograf",
        "Guitarbygger",
        "Frisør inden for teater- og TV-branchen",
        "Hundefrisør",
        "Skilærer",
        "Misbrugsbehandler",
        "VVS-tekniker",
        "Maskinkonstruktør",
        "Skibsingeniør",
        "Lægesekretærelev",
        "Social- og sundhedsassistentelev",
        "Filmklipperelev",
        "Laborantelev",
        "Elektronikfagtekniker-elev",
        "Finanselev",
        "Kokkeelev",
        "Guld- og sølvsmedelev",
        "Maskinsnedkerelev",
        "Teknisk designerelev",
        "Uddannelsesleder",
        "Kørselsleder",
        "Greenkeeper",
        "Kunsthåndværker",
        "Neurofysiologiassistent",
        "Ministerialbetjent",
        "Sekretariatschef",
        "Plejehjemsmedhjælper",
        "Psykomotorisk terapeut",
        "Sundhedsplejerske",
        "TV-producer",
        "Sejlmager",
        "Smørrebrødsjomfru",
        "Sanglærer",
        "Rengøringsassistent",
        "Vinduespudser",
        "Bademester",
        "Maskinfører",
        "Buschauffør",
        "Procesoperatør",
        "Bygningsmaler",
        "Flisemontør",
        "Gulvlægger",
        "Tæppemontør",
        "Hospitalsserviceassistent",
        "Arkivmedarbejder",
        "HR-assistent",
        "Korrespondent",
        "Purser",
        "Rideskoleassistent",
        "Dyrepasser",
        "Køkkenmedhjælper",
        "Opvasker",
        "Omdeler",
        "Renovationsarbejder",
        "Gadefejer",
        "Måleraflæser",
        "Pizzabager",
        "Fastfood ekspedient",
        "Butiksmedhjælper",
        "Landbrugsmedhjælper",
        "Gartner",
        "Skovarbejder",
        "Dambrugsarbejder",
        "Politiinspektør",
        "Speditionsleder",
        "Bygningsingeniør",
        "Energikonsulent",
        "Elektronikfagtekniker",
        "Lingvist",
        "Tegnsprogstolk",
        "Oversætter",
        "Tolk",
        "Journalist",
        "Dramaturg",
        "Forlagsredaktør",
        "Advokat",
        "Dommer",
        "Notar",
        "Jurist",
        "Produktudvikler",
        "Industritekniker",
        "Laboratorieassistent",
        "Biomediciner",
        "Apotekerassistent",
        "Apotekstekniker",
        "Ortopædiingeniør",
        "Klinisk tandtekniker",
        "Dyreklinikassistent",
        "Flyveleder",
        "Flyveklarerer",
        "Pilot",
        "Rejsekonsulent",
        "Trafikassistent",
        "Billetsælger",
        "Rejsebureaumedarbejder",
        "Medarbejder på turistkontor",
        "Inkassomedarbejder",
        "Specialtandlæge",
        "Dyrlæge",
        "Tandlæge",
        "Apoteker",
        "CSR-ansvarlig",
        "Projektleder",
        "Afdelingsleder",
        "Salgsdirektør",
        "Bygningskonstruktør",
        "Afdelingschef",
        "Fodermester",
        "Havneassistent",
        "Farmaceut",
        "Artdirector assistent",
        "Professor",
        "Faglærer",
        "Automontør",
        "Familieplejer",
        "Blomsterdekoratør",
        "Sundhedsøkonom",
        "Bilsynsassistent",
        "Badeassistent",
        "Businesscontroller",
        "Specialkonsulent",
        "FVU-lærer",
        "Bageriarbejder",
        "Ridelærer",
        "Fitness-instruktør",
        "Optiker",
        "Fotograf",
        "Fotojournalist",
        "Køkkenchef",
        "Regissør",
        "Salgschef",
        "Elinstallatør",
        "Skolekonsulent",
        "Læge",
        "Byggesagsbehandler",
        "Økologikonsulent",
        "Restaurantchef",
        "Cater",
        "Adjunkt",
        "Faglig konsulent",
        "Forsorgsmedarbejder",
        "Pædagogisk konsulent",
        "Sygehuslæge",
        "Hospitalsmedhjælper",
        "Kirkesanger",
        "Kantineleder",
        "Fagkonsulent",
        "Handicaphjælper",
        "Aftenskolelærer",
        "Projektkoordinator",
        "Ligestillingskonsulent",
        "Brolæggerarbejde",
        "Bygningsstruktør",
        "Oliefyrstekniker",
        "Motorcykelmekaniker",
        "Buschaufførelev",
        "Minkfarmmedhjælper",
        "Procesteknolog",
        "Rengøringsassistent i transportmidler",
        "Butiks- og detailslagter",
        "Audiologiassistent",
        "Skiltemalerlærling",
        "Rengøringsassistent i kontor",
        "Ventilationstekniker",
        "Skibsassistent",
        "AV teknikerelev",
        "Højskolelærer",
        "Detailhandelselev",
        "Forretningsudvikler",
        "Vinkyper",
        "Kulturmedarbejder",
        "Zoneterapeut",
        "Styrmand",
        "Turistchef",
        "Anæstesisygeplejerske",
        "Støttepædagog",
        "Salgskonsulent",
        "Eventkoordinatorelev",
        "Bygningssnedker",
        "Finansmedarbejder",
        "Kursuskoordinator",
        "Automatiktekniker",
        "Bioanalytiker",
        "Klubpædagog",
        "Vagtcentralleder",
        "Flyteknikner",
        "Forsyningsoperatør",
        "Account manager",
        "Datatekniker",
        "Logistikchef",
        "Tale-hørelærer",
        "Plastmager",
        "IT-produktchef",
        "Erhvervsanalytiker",
        "Halinspektør",
        "Maskinoperatør",
        "Kommunikationsmedarbejder",
        "Anlægsstruktør",
        "Filmtekniker",
        "Elektronikfagteknikerelev",
        "Servicetekniker",
        "Mejeriingeniør",
        "Poder",
        "Advokatfuldmægtig",
        "Omsorgshjælper",
        "Kvalitetsmedarbejder",
        "Forlagskonsulent",
        "Flyteknikerlærling",
        "Skov- og naturtekniker",
        "Skolesekretær",
        "IT-produktejer",
        "Kontorassistent",
        "Udviklingskonsulent",
        "Pædagogisk faglig koordinator",
    ]
