from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``da_DK`` locale.   # NOQA"""

    word_list = (
        "område",
        "verden",
        "nødvendig",
        "ligge",
        "magt",
        "drøm",
        "midt",
        "indeholde",
        "plads",
        "viden",
        "etage",
        "forstå",
        "social",
        "hvornår",
        "andre",
        "vente",
        "bære",
        "bank",
        "station",
        "budget",
        "hjerte",
        "politisk",
        "ret",
        "fod",
        "åben",
        "sammenligne",
        "national",
        "offer",
        "hver",
        "økonomi",
        "morgen",
        "masse",
        "bestemme",
        "race",
        "nogen",
        "forekomme",
        "at",
        "især",
        "kraft",
        "andet",
        "følelse",
        "bred",
        "problem",
        "hospital",
        "tusind",
        "TV",
        "bold",
        "vælge",
        "medicinsk",
        "dårligst",
        "ja",
        "miljø",
        "forlig",
        "netværk",
        "beskrive",
        "beløb",
        "publikum",
        "scene",
        "tanke",
        "form",
        "officer",
        "cykle",
        "celle",
        "løb",
        "passere",
        "spise",
        "efterår",
        "spekulerer",
        "luft",
        "medier",
        "kant",
        "tre",
        "rækkevidde",
        "møde",
        "resultat",
        "aftensmad",
        "uge",
        "overveje",
        "se",
        "ur",
        "forbrydelse",
        "os",
        "television",
        "krig",
        "videnskab",
        "eksempel",
        "stemme",
        "give",
        "forfatter",
        "hellere",
        "behandling",
        "senere",
        "syv",
        "par",
        "hundrede",
        "hud",
        "enkelt",
        "liste",
        "aften",
        "ud",
        "altid",
        "tryk",
        "effekt",
        "ting",
        "sager",
        "rød",
        "så",
        "hel",
        "vil",
        "have",
        "leder",
        "inde",
        "fordel",
        "taske",
        "aldrig",
        "forskellige",
        "artikel",
        "grine",
        "forklare",
        "jeg",
        "minut",
        "være",
        "eksisterer",
        "forkert",
        "rig",
        "dække",
        "konference",
        "sikker",
        "ejendom",
        "udmelding",
        "plukke",
        "blive",
        "ekspert",
        "hele",
        "vejen",
        "igennem",
        "år",
        "strøm",
        "store",
        "nå",
        "hende",
        "købe",
        "tegne",
        "fattige",
        "kort",
        "rolle",
        "sandsynligvis",
        "der",
        "placere",
        "familie",
        "forskning",
        "dag",
        "telefon",
        "kan",
        "mund",
        "finansiel",
        "evne",
        "design",
        "politik",
        "medlem",
        "anden",
        "lave",
        "læge",
        "skulle",
        "gerne",
        "myndighed",
        "dyrke",
        "sende",
        "kilde",
        "forbi",
        "arbejde",
        "århundrede",
        "dårligt",
        "interesse",
        "vest",
        "lade",
        "jeres",
        "vindue",
        "bestemte",
        "spørge",
        "sige",
        "dette",
        "operation",
        "lille",
        "miljømæssigt",
        "genkende",
        "tilbud",
        "ven",
        "fysisk",
        "nu",
        "svare",
        "hun",
        "ske",
        "syd",
        "fuld",
        "trods",
        "administration",
        "ny",
        "endelig",
        "fremstille",
        "besked",
        "figur",
        "skilt",
        "trin",
        "information",
        "forholde",
        "ned",
        "faktisk",
        "direkte",
        "succes",
        "tjene",
        "debat",
        "varme",
        "barn",
        "niveau",
        "fyr",
        "træ",
        "eftermiddagen",
        "karakter",
        "forlade",
        "sprog",
        "godt",
        "ind",
        "problemer",
        "underviser",
        "stor",
        "ryste",
        "bestyrelse",
        "gå",
        "central",
        "synge",
        "ord",
        "oplade",
        "datter",
        "adresse",
        "hed",
        "seng",
        "rapport",
        "over",
        "penge",
        "alder",
        "tendens",
        "køkken",
        "arbejder",
        "tilstand",
        "side",
        "bekymre",
        "blod",
        "vigtigste",
        "bedst",
        "sang",
        "imidlertid",
        "nævne",
        "tab",
        "hit",
        "vellykket",
        "virkelig",
        "tage",
        "smerte",
        "professor",
        "mørk",
        "vind",
        "årti",
        "hotel",
        "projekt",
        "traditionel",
        "indvirkning",
        "kollektion",
        "seksuel",
        "pris",
        "skulder",
        "rejse",
        "finde",
        "interview",
        "ifølge",
        "grad",
        "medarbejder",
        "trussel",
        "sommer",
        "stå",
        "hvorfor",
        "pæn",
        "individuel",
        "avis",
        "industri",
        "nat",
        "alle",
        "bruge",
        "handling",
        "vej",
        "hård",
        "brev",
        "olie",
        "ved",
        "påvirke",
        "parat",
        "stærk",
        "vigtig",
        "ressource",
        "værdi",
        "påstand",
        "struktur",
        "virkelighed",
        "disse",
        "komme",
        "data",
        "position",
        "glemme",
        "vægt",
        "af",
        "mål",
        "varsel",
        "prøve",
        "jord",
        "død",
        "blå",
        "strategi",
        "vend",
        "tilbage",
        "læs",
        "start",
        "bedre",
        "vise",
        "selvom",
        "konto",
        "på",
        "måle",
        "kvalitet",
        "nord",
        "vestlig",
        "skyde",
        "liv",
        "køre",
        "sandhed",
        "kunstner",
        "jo",
        "da",
        "formue",
        "bjørn",
        "historiker",
        "du",
        "titel",
        "udenlandsk",
        "kontanter",
        "korn",
        "heller",
        "ikke",
        "overlevelse",
        "beskytte",
        "baseball",
        "før",
        "forhandle",
        "afhængig",
        "fase",
        "genetisk",
        "stille",
        "fugl",
        "grøntsag",
        "tillid",
        "episode",
        "kunstnerisk",
        "markedsføring",
        "perfekt",
        "afspejle",
        "emne",
        "jet",
        "synlig",
        "ugentlig",
        "undersøgelse",
        "tank",
        "enhed",
        "gensidig",
        "psykolog",
        "fru",
        "øjeblikket",
        "indlysende",
        "årsag",
        "tilstedeværelse",
        "parkering",
        "forår",
        "tå",
        "muskel",
        "fange",
        "frokost",
        "forpligtelse",
        "spænding",
        "tilhører",
        "gentleman",
        "mig",
        "jury",
        "eventuelt",
        "gård",
        "alsidig",
        "passager",
        "øjeblik",
        "jæger",
        "vane",
        "erkende",
        "erhverve",
        "livsstil",
        "respons",
        "landdistrikter",
        "fantasi",
        "afgørende",
        "langt",
        "fond",
        "insistere",
        "parkere",
        "opnå",
        "fløde",
        "forskel",
        "væsentligt",
        "lappe",
        "morder",
        "længde",
        "poesi",
        "udbredt",
        "ungdom",
        "fjerde",
        "bevæbnet",
        "mirakel",
        "musiker",
        "bind",
        "punkt",
        "frihed",
        "rør",
        "genopretning",
        "forhandler",
        "kun",
        "ben",
        "klinge",
        "nød",
        "tænker",
        "græsplæne",
        "lag",
        "sko",
        "røg",
        "blandt",
        "karriere",
        "angst",
        "dimension",
        "vital",
        "kerne",
        "gul",
        "tælle",
        "forventer",
        "klinik",
        "opbevaring",
        "relevant",
        "måske",
        "meget",
        "egen",
        "chip",
        "trykke",
        "stil",
        "sofistikeret",
        "begrænsning",
        "resterende",
        "pulver",
        "slag",
        "fiktion",
        "aggressiv",
        "anholdelse",
        "syre",
        "glip",
        "afslut",
        "igangværende",
        "afvige",
        "forestille",
        "inflation",
        "regnet",
        "te",
        "sværge",
        "afdeling",
        "DNA",
        "tåre",
        "skib",
        "frembringe",
        "ivrige",
        "tilføjelse",
        "boliger",
        "bombe",
        "helikopter",
        "tag",
        "negativ",
        "regn",
        "dokument",
        "omdømme",
        "sikkert",
        "peber",
        "retfærdig",
        "skygge",
        "type",
        "distrikt",
        "betaling",
        "kontrast",
        "opdage",
        "signal",
        "gnide",
        "svært",
        "uanset",
        "sikkerhed",
        "ovn",
        "major",
        "butik",
        "forsigtigt",
        "flygtning",
        "korrekt",
        "bro",
        "men",
        "kunst",
        "religion",
        "forsøg",
        "kost",
        "kunne",
        "levende",
        "gevinst",
        "kolesterol",
        "sovs",
        "bag",
        "i",
        "billede",
        "desuden",
        "modtage",
        "udgave",
        "hal",
        "skelne",
        "anerkende",
        "bygge",
        "nummer",
        "distribuere",
        "væk",
        "fortælle",
        "mysterium",
        "siden",
        "samling",
        "gen",
        "stof",
        "global",
        "stjæle",
        "funktion",
        "præsidentvalg",
        "respekt",
        "løg",
        "beundre",
        "sælge",
        "mangfoldighed",
        "vidner",
        "fejl",
        "domfældelse",
        "teenager",
        "solid",
        "fødselsdag",
        "som",
        "formand",
        "konkurrence",
        "er",
        "indsigt",
        "nærheden",
        "betyde",
        "annonce",
        "dem",
        "skære",
        "reaktion",
        "romantisk",
        "smag",
        "udgør",
        "lethed",
        "misbrug",
        "sukker",
        "støj",
        "senat",
        "syg",
        "forvirring",
        "formål",
        "trick",
        "hul",
        "klaver",
        "operere",
        "grave",
        "gætte",
        "regime",
        "model",
        "sommetider",
        "politimand",
        "nødsituation",
        "rigtigt",
        "træt",
        "laver",
        "mad",
        "investere",
        "reb",
        "ofte",
        "restaurant",
        "ekstraordinær",
        "fortælling",
        "angreb",
        "størrelse",
        "stjerne",
        "overraskende",
        "elementære",
        "kommunikere",
        "top",
        "til",
        "fødsel",
        "spiseskefuld",
        "konventionelle",
        "køretøj",
        "film",
        "gear",
        "kul",
        "væg",
        "køn",
        "voldsom",
        "vin",
        "værdifuld",
        "forlægger",
        "session",
        "fabrikant",
        "arkitekt",
        "direktør",
        "begge",
        "ødelæggelse",
        "permanent",
        "kristen",
        "klatre",
        "økonom",
        "sats",
        "kæledyr",
        "særlig",
        "metode",
        "tro",
        "tid",
        "konsensus",
        "spids",
        "kategori",
        "forstyrre",
        "terrorist",
        "klare",
        "kat",
        "ønske",
        "tur",
        "skønhed",
        "knap",
        "print",
        "mulighed",
        "rette",
        "høring",
        "levested",
        "bebrejde",
        "øverst",
        "underskud",
        "veje",
        "virksomhed",
        "helt",
        "implementere",
        "produktion",
        "sol",
        "stand",
        "plan",
        "omfavne",
        "batteri",
        "sind",
        "håndbevægelse",
        "husstand",
        "lastbil",
        "begreb",
        "udseende",
        "dræbe",
        "sig",
        "selv",
        "hjælpe",
        "bevise",
        "universel",
        "tekst",
        "uafhængighed",
        "snart",
        "nødvendigvis",
        "sektor",
        "alkohol",
        "ansvarlig",
        "besøg",
        "ly",
        "kvarter",
        "smuds",
        "bidrag",
        "kamp",
        "ankomme",
        "fodbold",
        "spejl",
        "ventilator",
        "skæbne",
        "majs",
        "kræft",
        "spore",
        "legeme",
        "udvælgelse",
        "uddanne",
        "fisk",
        "diagram",
        "stående",
        "massiv",
        "byrde",
        "tilladelse",
        "samme",
        "måler",
        "vælg",
        "person",
        "tilstrækkelig",
        "vedtage",
        "instruktion",
        "musikalsk",
        "bevare",
        "kop",
        "gentage",
        "skrivebord",
        "sjæl",
        "nyttig",
        "fuldt",
        "nærme",
        "overbevise",
        "psykologi",
        "detaljeret",
        "dom",
        "kyst",
        "profil",
        "finansiere",
        "tale",
        "repræsentant",
        "reagere",
        "tegning",
        "mandskab",
        "sekvens",
        "konsulent",
        "formode",
        "skov",
        "skjule",
        "lunge",
        "ankomst",
        "hjemløs",
        "kirke",
        "spændende",
        "guld",
        "time",
        "alligevel",
        "flytte",
        "begavet",
        "brug",
        "koncentration",
        "desperat",
        "væsen",
        "radio",
        "skrig",
        "million",
        "objektiv",
        "nederlag",
        "nederste",
        "holde",
        "senior",
        "matematik",
        "support",
        "rose",
        "pund",
        "hegn",
        "medlemskab",
        "tilmeld",
        "gyldige",
        "forsvar",
        "brun",
        "kæmpe",
        "privat",
        "investering",
        "fejre",
        "advarsel",
        "foreslå",
        "overrasket",
        "mord",
        "garanti",
        "berømthed",
        "frugt",
        "match",
        "alene",
        "tættere",
        "søg",
        "flaske",
        "kriterier",
        "offentlig",
        "centrum",
        "argument",
        "stat",
        "formel",
        "opgave",
        "teknologi",
        "magtfulde",
        "sammenhæng",
        "søge",
        "chef",
        "villig",
        "bekymring",
        "uddannelse",
        "ville",
        "overse",
        "flad",
        "højttaler",
        "forsvinde",
        "lige",
        "forbyde",
        "forbedre",
        "besøgende",
        "lancering",
        "baggrund",
        "pie",
        "lugt",
        "klinisk",
        "udvej",
        "alternativ",
        "afgrøde",
        "øge",
        "dele",
        "indsats",
        "vært",
        "betyder",
        "find",
        "immigrant",
        "lænke",
        "konstant",
        "strategisk",
        "stipendium",
        "skuldertræk",
        "rådgiver",
        "bage",
        "udbyder",
        "løbet",
        "enorm",
        "binde",
        "omsorg",
        "flyve",
        "tung",
        "indkomst",
        "let",
        "bevægelse",
        "opstå",
        "bruser",
        "hen",
        "imod",
        "fylde",
        "mekanisme",
        "tæt",
        "nylig",
        "pensionering",
        "procedure",
        "generelt",
        "henvise",
        "oversætte",
        "tildele",
        "indpakning",
        "medhjælper",
        "næste",
        "håndværk",
        "dybt",
        "specialist",
        "strand",
        "fundament",
        "mejse",
        "overvinde",
        "plante",
        "hej",
        "initial",
        "forhandling",
        "hals",
        "måne",
        "støvle",
        "kongres",
        "forberedelse",
        "minde",
        "opmærksomhed",
        "afsnit",
        "kunde",
        "undskyld",
        "afstand",
        "din",
        "passe",
        "hus",
        "odds",
        "nogle",
        "udvikling",
        "skandale",
        "med",
        "kok",
        "tårn",
        "invitere",
        "skade",
        "konflikt",
        "fordi",
        "guvernør",
        "også",
        "rolige",
        "natur",
        "hvordan",
        "venlig",
        "ledsage",
        "borgmester",
        "via",
        "stolt",
        "gammel",
        "erstatte",
        "lejlighed",
        "kritisk",
        "forudsige",
        "fed",
        "attribut",
        "vagt",
        "vi",
        "forurening",
        "nation",
        "transportør",
        "søn",
        "de",
        "umulig",
        "hør",
        "opskrift",
        "underholdning",
        "brændstof",
        "live",
        "univers",
        "glide",
        "foreslog",
        "indre",
        "sne",
        "krænkelse",
        "sky",
        "masser",
        "provins",
        "gal",
        "institution",
        "henviser",
        "moderne",
        "initiativ",
        "republikansk",
        "begravelse",
        "urban",
        "begrænset",
        "sent",
        "flyselskab",
        "kage",
        "bekostning",
        "album",
        "lyd",
        "rykke",
        "følge",
        "mursten",
        "super",
        "snor",
        "høj",
        "kaffe",
        "vågne",
        "leje",
        "universitetsområde",
        "bånd",
        "defensiv",
        "had",
        "udvidelse",
        "mere",
        "facilitet",
        "variere",
        "våben",
        "styrke",
        "junior",
        "faret",
        "vild",
        "hemmelighed",
        "stirre",
        "efter",
        "tom",
        "eliminere",
        "personale",
        "version",
        "bogstaveligt",
        "talt",
        "sædvanlig",
        "adgang",
        "observation",
        "opførsel",
        "fiasko",
        "psykologisk",
        "fænomen",
        "deltage",
        "informere",
        "indtægter",
        "beslutte",
        "sjovt",
        "høre",
        "under",
        "synes",
        "råd",
        "reduktion",
        "japansk",
        "overalt",
        "programmmere",
        "brygge",
    )

    parts_of_speech: Dict[str, tuple] = {}
