from .. import Provider as JobProvider


class Provider(JobProvider):
    """Translated from Super class"""

    jobs = (
        "Administrátor, umenie",
        "Administrátor, štátna služba",
        "Advokát",
        "Advokát pre ochranné známky",
        "Akademický knihovník",
        "Akupunkturista",
        "Analytický chemik",
        "Analytik finančného rizika",
        "Angličtina ako lektorka cudzieho jazyka",
        "Angličtina ako učiteľka druhého jazyka",
        "Animátor",
        "Arborista",
        "Archeológ",
        "Architekt",
        "Architektonický technológ",
        "Archivár",
        "Arteterapeut",
        "Asistent politika",
        "Astronóm",
        "Audiologický vedec",
        "Automobilový inžinier",
        "Autorizovaný likvidátor strát",
        "Autorizovaný účtovník",
        "Autorizovaný účtovník v oblasti verejných financií",
        "Bankár",
        "Banský inžinier",
        "Barista",
        "Biochemik, klinický",
        "Biomedicínsky inžinier",
        "Biomedicínsky vedec",
        "Bylinkár",
        "Bytový manažér / referent",
        "Charitatívny úradník",
        "Chemický inžinier",
        "Chemik, analytický",
        "Chiropraktik",
        "Chirurg",
        "Copywriter, reklama",
        "Cytogenetik",
        "Daňový poradca",
        "Detská sestra",
        "Detský psychoterapeut",
        "Diagnostický rádiograf",
        "Dietológ",
        "Dizajnér, fúkané sklo / vitráž",
        "Dizajnér, grafik",
        "Dizajnér, interiér / priestor",
        "Dizajnér, keramika / hrnčiarstvo",
        "Dizajnér, multimédiá",
        "Dizajnér, móda / oblečenie",
        "Dizajnér, nábytok",
        "Dizajnér, priemyselný / produkt",
        "Dizajnér, televízia / film",
        "Dizajnér, textil",
        "Dizajnér, výstava / výstava",
        "Dizajnér, šperky",
        "Docent",
        "Dodávateľ",
        "Dospelý poradenský pracovník",
        "Dozorca",
        "Dramatický terapeut",
        "Dôstojník obchodného námorníctva",
        "Dôstojník pre ochranu prírody",
        "Dôstojník pre výcvik a vzdelávanie ozbrojených síl",
        "Editor funkcie časopisu",
        "Ekológ",
        "Ekonóm",
        "Elektroinžinier",
        "Embryológ, klinický",
        "Energetický inžinier",
        "Energetický manažér",
        "Environmentálny manažér",
        "Ergonóm",
        "Farebný technológ",
        "Farmaceut Spoločenstva",
        "Farmakológ",
        "Filmový / video editor",
        "Financny kontrolor",
        "Finančný manažér",
        "Finančný obchodník",
        "Finančný plánovač",
        "Finančný poradca",
        "Finančný riaditeľ",
        "Firemná sekretárka",
        "Fotograf",
        "Fytoterapeut",
        "Fyzik zdravia",
        "Fyzik, lekár",
        "Fyziologický vedec",
        "Fyziológ cvičenia",
        "Fyzioterapeut",
        "Fúkač skla / dizajnér",
        "Genetik, molekulárny",
        "Geochemik",
        "Geodet minerálov",
        "Geodet poistného rizika",
        "Geofyzik / terénny seizmológ",
        "Geológ, strojárstvo",
        "Geológ",
        "Geovedec",
        "Grafický dizajnér",
        "Grafik",
        "Hasič",
        "Hematológ",
        "Herec",
        "Herpetológ",
        "Hlavný marketingový riaditeľ",
        "Homeopat",
        "Hotelový manažér",
        "Hudobník",
        "Hudobný lektor",
        "Hudobný terapeut",
        "Hutník",
        "Hydrogeológ",
        "Hydrografický geodet",
        "Hydrológ",
        "Hygienik práce",
        "IT konzultant",
        "Ilustrátor",
        "Imunológ",
        "Informačný úradník",
        "Investičný analytik",
        "Investičný bankár, funkčný",
        "Investičný bankár, podnikový",
        "Inšpektor / hodnotiteľ reklamácií",
        "Inšpektor historických budov / referent pamiatkovej starostlivosti",
        "Inšpektor plánovania a rozvoja",
        "Inšpektor zdravia a bezpečnosti",
        "Inžinier budov",
        "Inžinier elektroniky",
        "Inžinier kontroly a prístrojového vybavenia",
        "Inžinier poľnohospodárstva",
        "Inžinier pre automobilový priemysel",
        "Inžinier výrobných systémov",
        "Inžinier, baníctvo",
        "Inžinier, biomedicínsky",
        "Inžinier, chemický",
        "Inžinier, elektronika",
        "Inžinier, elektrotechnik",
        "Inžinier, energia",
        "Inžinier, komunikácia",
        "Inžinier, letecký",
        "Inžinier, materiály",
        "Inžinier, pozemok",
        "Inžinier, poľnohospodár",
        "Inžinier, riadenie a prístrojové vybavenie",
        "Inžinier, ropa",
        "Inžinier, statik",
        "Inžinier, stavebné služby",
        "Inžinier, stavebný (zmluvný)",
        "Inžinier, stavebný inžinier (poradenstvo)",
        "Inžinier, technický predaj",
        "Inžinier, voda",
        "Inžinier, vysielanie (prevádzka)",
        "Inžinier, výroba",
        "Inžinier, výroba",
        "Inžinier, výrobné systémy",
        "Inžinier, vŕtanie",
        "Inžinier, web",
        "Inžinier, údržba",
        "Inžinier, údržba (IT)",
        "Inžiniersky geológ",
        "Kameraman",
        "Kariérny informačný úradník",
        "Kariérny poradca",
        "Kariérny poradca pre vysokoškolské vzdelávanie",
        "Kartograf",
        "Klinický biochemik",
        "Klinický cytogenetik",
        "Klinický embryológ",
        "Klinický molekulárny genetik",
        "Klinický psychológ",
        "Klinický vedec, histokompatibilita a imunogenetika",
        "Knihovník",
        "Knihovník, verejný",
        "Kníhkupec",
        "Komerčný / rezidenčný geodet",
        "Komerčný záhradník",
        "Komunikačný inžinier",
        "Komunitný umelecký pracovník",
        "Konateľ spoločnosti",
        "Kontrolór",
        "Konzervátor / reštaurátor nábytku",
        "Konzervátor múzea / galérie",
        "Konzervátor, múzeum / galéria",
        "Konzervátor, nábytok",
        "Konzultant pre dôchodky",
        "Konzultácia so stavebným inžinierom",
        "Koordinátor dobrovoľníctva",
        "Kupujúci, maloobchod",
        "Kurátor",
        "Kurátor múzea / galérie",
        "Lektor ďalšieho vzdelávania",
        "Lektor, vysokoškolské vzdelanie",
        "Lektor, ďalšie vzdelávanie",
        "Lekár všeobecného lekára",
        "Lekár, nemocnica",
        "Lekár, všeobecná prax",
        "Lekárnik, komunita",
        "Lekárnik, nemocnica",
        "Lekársky fyzik",
        "Lekársky ilustrátor",
        "Lekársky obchodný zástupca",
        "Lekársky sekretár",
        "Lekársky technický pracovník",
        "Letecký dispečer",
        "Letecký inžinier",
        "Letecký sprostredkovateľ",
        "Lexikograf",
        "Licencovaný dopravca",
        "Lobista",
        "Logistika / podpora / administratívny dôstojník ozbrojených síl",
        "Manažér call centra",
        "Manažér cestovnej kancelárie",
        "Manažér divadelnej scény",
        "Manažér farmy",
        "Manažér fitnescentra",
        "Manažér informačných systémov",
        "Manažér komerčnej umeleckej galérie",
        "Manažér logistiky a distribúcie",
        "Manažér stravovania",
        "Manažér umeleckej galérie",
        "Manažér zariadení",
        "Manažér zábavného parku",
        "Manžérsky konzultant",
        "Marketingový manažér",
        "Materiálový inžinier",
        "Mediálny plánovač",
        "Meteorológ",
        "Mikrobiológ",
        "Moderátor, vysielanie",
        "Morský vedec",
        "Multimediálne programy",
        "Módny návrhár",
        "Najlepší chlapec",
        "Nemocničný lekár",
        "Nemocničný lekárnik",
        "Neurochirurg",
        "Novinár novín",
        "Novinár časopisu",
        "Novinár, noviny",
        "Novinár, vysielanie",
        "Novinár, časopis",
        "Nákupca médií",
        "Nákupca, priemyselný",
        "Námorný architekt",
        "Návrhár interiérov a priestorov",
        "Návrhár nábytku",
        "Návrhár výstavy",
        "Návrhár šperkov",
        "Návrhárka keramiky",
        "Obchodník s akciami",
        "Obchodník s dlhopismi",
        "Obchodník s futures",
        "Oceánograf",
        "Ochranár, historické budovy",
        "Odborník na životné prostredie",
        "Odevný / textilný technológ",
        "Onkológ",
        "Operatívny výskumník",
        "Operačný dôstojník diplomatických služieb",
        "Operačný dôstojník ozbrojených síl",
        "Optik, výdaj",
        "Optometristu",
        "Organizácia podujatia",
        "Ortoptista",
        "Osobný asistent",
        "Osteopat",
        "Očný lekár",
        "Palubní sprievodcovia",
        "Patent attorney",
        "Patológ",
        "Pedagogický psychológ",
        "Pedikér",
        "Personalista",
        "Pilot leteckej spoločnosti",
        "Plánovač dopravy",
        "Plánovač reklamného účtu",
        "Plánovač tlače",
        "Podnikový investičný bankár",
        "Podnikový pokladník",
        "Poistný matematik",
        "Poisťovací maklér",
        "Poisťovateľ",
        "Police officer",
        "Poradca pre zdravie a bezpečnosť",
        "Poradca pre životné prostredie",
        "Poradenská pracovníčka",
        "Poradenský psychológ",
        "Posádka",
        "Potravinársky technológ",
        "Poľnohospodársky konzultant",
        "Pracovník medzinárodnej pomoci / rozvoja",
        "Pracovník pomoci",
        "Pracovník rozvoja komunity",
        "Pracovník s mládežou",
        "Pracovný psychológ",
        "Pracovný terapeut",
        "Predajca",
        "Prekladateľ",
        "Prevádzkovateľ televíznej kamery",
        "Prevádzkový geológ",
        "Prevádzkový investičný bankár",
        "Prevádzkový riaditeľ",
        "Priemyselný / produktový dizajnér",
        "Priemyselný kupujúci",
        "Prieskumník trhu",
        "Prieskumový pracovník",
        "Probačný úradník",
        "Producent, rádio",
        "Producent, televízia / film / video",
        "Production assistant, radio",
        "Production assistant, television",
        "Production designer, theatre/television/film",
        "Production engineer",
        "Production manager",
        "Produktový dizajnér",
        "Produktový manažér",
        "Professor Emeritus",
        "Programme researcher, broadcasting/film/video",
        "Programmer, applications",
        "Programmer, multimedia",
        "Programmer, systems",
        "Proofreader",
        "Právnik",
        "Právny tajomník",
        "Prázdninový zástupca",
        "Psychiatric nurse",
        "Psychiatrist",
        "Psychologist, clinical",
        "Psychologist, counselling",
        "Psychologist, educational",
        "Psychologist, forensic",
        "Psychologist, occupational",
        "Psychologist, prison and probation services",
        "Psychologist, sport and exercise",
        "Psychoterapeut tanečného pohybu",
        "Psychoterapeut",
        "Pôda",
        "Pôrodná asistentka",
        "Manažér kvality",
        "Radca",
        "Realitný maklér",
        "Redaktor, uvedenie do prevádzky",
        "Redakčný asistent",
        "Referent cestovného ruchu",
        "Referent environmentálnej výchovy",
        "Referent geografických informačných systémov",
        "Referent komunitného vzdelávania",
        "Referent múzejného vzdelávania",
        "Referent obchodných noriem",
        "Referent ochrany prírody",
        "Referent odbornej prípravy a rozvoja",
        "Referent odborového výskumu",
        "Referent poľných pokusov",
        "Referent pre núdzové plánovanie / riadenie",
        "Referent pre rovnosť a rozmanitosť",
        "Referent pre výstavy v múzeách / galériách",
        "Referent rozvoja umenia",
        "Referent technickej podpory IT",
        "Referent výstavy, múzeum / galéria",
        "Referent ľudských zdrojov",
        "Referent školstva pre životné prostredie",
        "Referent školstva, komunita",
        "Referent školstva, múzeum",
        "Regulátor strát, objednaný",
        "Reklamný textár",
        "Reklamný umelecký riaditeľ",
        "Riaditeľ pre stratégiu",
        "Ropný inžinier",
        "Rozvojový pracovník, komunita",
        "Rozvojový pracovník, medzinárodná pomoc",
        "Rýchly streamer pre štátnu službu",
        "Sanitka",
        "Sestra pre dospelých",
        "Sestra pre duševné zdravie",
        "Sestra s poruchami učenia",
        "Sestra, detská",
        "Sestra, dospelý",
        "Sestra, porucha učenia",
        "Sieťový inžinier",
        "Spisovateľ",
        "Spolupracovník pre klinický výskum",
        "Spracovateľ geofyzikálnych údajov",
        "Spravodajský analytik",
        "Správca",
        "Správca databázy",
        "Správca dedičstva",
        "Správca dôchodkového systému",
        "Správca lesov a lesov",
        "Správca nehnuteľnosti / pozemkový agent",
        "Správca poistného účtu",
        "Správca polohy",
        "Správca spracovania údajov",
        "Správca umenia",
        "Správca zákazníckeho centra",
        "Správca školstva",
        "Správca štátnej služby",
        "Správca, charitatívne / dobrovoľnícke organizácie",
        "Správca, miestna samospráva",
        "Správca, vzdelávanie",
        "Správca, šport",
        "Stavebný geodet",
        "Stavebný inžinier, poradenstvo",
        "Stavebný inžinier, uzatváranie zmlúv",
        "Strihač, film / video",
        "Strojný inžinier",
        "Strážca / strážca",
        "Svetelný technik, vysielanie / film / video",
        "Súdny psychológ",
        "Súdny vedec",
        "Súkromný učiteľ hudby",
        "Tanečnica",
        "Technický dôstojník ozbrojených síl",
        "Technik údržby",
        "Technológ pre zvieratá",
        "Technológ varenia piva",
        "Terapeut, dráma",
        "Terapeut, hudba",
        "Terapeut, záhradnícky",
        "Terapeut, šport",
        "Terénny seizmológ",
        "Tlačový fotograf",
        "Tlmočník",
        "Toxikológ",
        "Umelec",
        "Urobiť",
        "Uvádzací redaktor",
        "Učiaci sa mentor",
        "Učiteľ v ranom detstve",
        "Učiteľ, angličtina ako cudzí jazyk",
        "Učiteľ, hudba",
        "Učiteľ, prvé roky / pred",
        "Učiteľ, vzdelávanie dospelých",
        "Učiteľ, základná škola",
        "Učiteľka na základnej škole",
        "Vedec dát",
        "Vedec pre kvalitu vody",
        "Vedec vývoja produktov / procesov",
        "Vedecký pracovník lekárskeho laboratória",
        "Vedúci kancelárie",
        "Vedúci konferenčného centra",
        "Vedúci osobnej dopravy",
        "Vedúci outdoorových aktivít / vzdelávania",
        "Vedúci reklamného účtu",
        "Vedúci reštaurácie rýchleho občerstvenia",
        "Vedúci rybej farmy",
        "Vedúci skladu",
        "Vedúci strediska voľného času",
        "Vedúci turistického informačného centra",
        "Vedúci ubytovania",
        "Vedúci zdravotníckej služby",
        "Vedúci úseku",
        "Veterinárny chirurg",
        "Video editor",
        "Vizuálny obchodník",
        "Vládny úradník pre sociálny výskum",
        "Vodný inžinier",
        "Vrtný inžinier",
        "Vybavenie záhradník",
        "Vybavovač poistných udalostí",
        "Vysielaný novinár",
        "Vysokoškolský lektor",
        "Výdajný optik",
        "Výkonný riaditeľ",
        "Výkonný technický riaditeľ",
        "Výrobný inžinier",
        "Výtvarný umelec",
        "Vývojár aplikácií",
        "Vývojár hier",
        "Vývojár počítačových hier",
        "Vývojár systémov",
        "Výživový poradca pre zvieratá",
        "Výživový terapeut",
        "Web dizajnér",
        "Wellsite geológ",
        "Zamestnanec imigračného úradu",
        "Zdravotná sestra, duševné zdravie",
        "Zdravotný návštevník",
        "Zememerač / geomatik",
        "Zmluvný stavebný inžinier",
        "Zubár",
        "Záchranár",
        "Záhradnícky konzultant",
        "Záhradnícky terapeut",
        "Záhradník, komerčný",
        "Záhradník, vybavenosť",
        "Záhradný architekt",
        "Záznamník bahna",
        "Úradník miestnej samosprávy",
        "Úradník pre rybolov",
        "Účtovník, autorizované verejné financie",
        "Účtovník, autorizovaný",
        "Účtovník, autorizovaný certifikovaný",
        "Účtovník, autorizovaný manažment",
        "Účtovný technik",
        "Špecialista na multimédiá",
        "Špecialista na podporu zdravia",
        "Špeditér",
        "Šľachtiteľ rastlín / genetik",
    )

    def job(self) -> str:
        return self.random_element(self.jobs)
